@@ -124,6 +124,8 @@ class Polynomial2D:
             popt,pcov = curve_fit(self._n4,xx,yy)
         elif norder==5:
             popt,pcov = curve_fit(self._n5,xx,yy)
+        elif norder==6:
+            popt,pcov = curve_fit(self._n6,xx,yy)
         else:
             popt,pcov = None,None
             print('Not support this norder')
@@ -170,6 +172,20 @@ class Polynomial2D:
         tmp += c32*np.power(x1,3)*np.power(x2,2) + c23*np.power(x1,2)*np.power(x2,3) 
         tmp += c14*x1*np.power(x2,4) + c05*np.power(x2,5)
         return tmp
+    def _n6(self,x,c00,c10,c01,c20,c11,c02,
+            c30,c21,c12,c03,c40,c31,c22,c13,c04,
+            c50,c41,c32,c23,c14,c05,
+            c60,c51,c42,c33,c24,c15,c06
+           ):
+        x1,x2=x
+        tmp = self._n5(x,c00,c10,c01,c20,c11,c02,
+                       c30,c21,c12,c03,c40,c31,c22,c13,c04,
+                       c50,c41,c32,c23,c14,c05
+                      )
+        tmp += c60*np.power(x1,6) + c51*np.power(x1,5)*x2 + c42*np.power(x1,4)*np.power(x2,2)
+        tmp += c33*np.power(x1,3)*np.power(x2,3) + c24*np.power(x1,2)*np.power(x2,4) 
+        tmp += c15*x1*np.power(x2,5) + c06*np.power(x2,6)
+        return tmp
     ##########
     ##########
     def _coefsize(self):
